[gegl] %s/gegl_list_properties/gegl_operation_list_properties/



commit 4ccee9b6513751c6cf4913ee0ca65b43b43f954d
Author: Ãyvind KolÃs <pippin gimp org>
Date:   Thu Mar 29 18:47:25 2012 +0100

    %s/gegl_list_properties/gegl_operation_list_properties/

 bindings/pygegl/Gegl/gegl.defs     |    2 +-
 bindings/pygegl/Gegl/gegl.override |    6 +++---
 bindings/rgegl/src/rgegl-node.c    |    2 +-
 gegl/gegl-dot.c                    |    2 +-
 gegl/gegl-xml.c                    |    2 +-
 gegl/gegl.h                        |    6 +++---
 gegl/operation/gegl-operation.c    |    4 ++--
 gegl/operation/gegl-operation.h    |    3 +--
 8 files changed, 13 insertions(+), 14 deletions(-)
---
diff --git a/bindings/pygegl/Gegl/gegl.defs b/bindings/pygegl/Gegl/gegl.defs
index c145290..ac5c377 100644
--- a/bindings/pygegl/Gegl/gegl.defs
+++ b/bindings/pygegl/Gegl/gegl.defs
@@ -84,7 +84,7 @@
 )
 
 (define-function list_properties
-  (c-name "gegl_list_properties")
+  (c-name "gegl_operation_list_properties")
   (return-type "GParamSpec**")
   (parameters
     '("const-gchar*" "operation_type")
diff --git a/bindings/pygegl/Gegl/gegl.override b/bindings/pygegl/Gegl/gegl.override
index 77b119d..7d5c2ab 100644
--- a/bindings/pygegl/Gegl/gegl.override
+++ b/bindings/pygegl/Gegl/gegl.override
@@ -158,9 +158,9 @@ _wrap_gegl_list_operations(PyObject *self)
     return ret;
 }
 %%
-override gegl_list_properties kwargs
+override gegl_operation_list_properties kwargs
 static PyObject *
-_wrap_gegl_list_properties(PyObject *self, PyObject *args, PyObject *kwargs)
+_wrap_gegl_operation_list_properties(PyObject *self, PyObject *args, PyObject *kwargs)
 {
     char *operation;
     guint n_properties, i;
@@ -174,7 +174,7 @@ _wrap_gegl_list_properties(PyObject *self, PyObject *args, PyObject *kwargs)
                                      &operation))
         return NULL;
 
-    properties = gegl_list_properties(operation, &n_properties);
+    properties = gegl_operation_list_properties(operation, &n_properties);
 
     ret = PyTuple_New(n_properties);
     if (!ret) {
diff --git a/bindings/rgegl/src/rgegl-node.c b/bindings/rgegl/src/rgegl-node.c
index b4666aa..3e84d08 100644
--- a/bindings/rgegl/src/rgegl-node.c
+++ b/bindings/rgegl/src/rgegl-node.c
@@ -222,7 +222,7 @@ clist_properties (self, op_type)
   VALUE ary;
   int i;
 
-  props = gegl_list_properties(RVAL2CSTR(op_type), &n_properties);
+  props = gegl_operation_list_properties(RVAL2CSTR(op_type), &n_properties);
   ary = rb_ary_new();
   for (i = 0; i < n_properties; i++){
       rb_ary_push (ary, rbgobj_ruby_object_from_instance(props[i])); /*rb_str_new2(props[i]->name));*/
diff --git a/gegl/gegl-dot.c b/gegl/gegl-dot.c
index 4f3e90a..a2bd9d9 100644
--- a/gegl/gegl-dot.c
+++ b/gegl/gegl-dot.c
@@ -79,7 +79,7 @@ gegl_dot_util_add_node (GString  *string,
   if (1)
     {
       guint        n_properties;
-      GParamSpec **properties = gegl_list_properties (gegl_node_get_operation (node), &n_properties);
+      GParamSpec **properties = gegl_operation_list_properties (gegl_node_get_operation (node), &n_properties);
       guint        i;
       for (i = 0; i < n_properties; i++)
         {
diff --git a/gegl/gegl-xml.c b/gegl/gegl-xml.c
index 10cf408..90cdecb 100644
--- a/gegl/gegl-xml.c
+++ b/gegl/gegl-xml.c
@@ -762,7 +762,7 @@ serialize_properties (SerializeState *ss,
   gboolean     got_a_param = FALSE;
   gint         i;
 
-  properties = gegl_list_properties (gegl_node_get_operation (node),
+  properties = gegl_operation_list_properties (gegl_node_get_operation (node),
                                      &n_properties);
 
   for (i = 0; i < n_properties; i++)
diff --git a/gegl/operation/gegl-operation.c b/gegl/operation/gegl-operation.c
index 558c88d..97814f5 100644
--- a/gegl/operation/gegl-operation.c
+++ b/gegl/operation/gegl-operation.c
@@ -343,8 +343,8 @@ get_invalidated_by_change (GeglOperation        *self,
 /* returns a freshly allocated list of the properties of the object, does not list
  * the regular gobject properties of GeglNode ('name' and 'operation') */
 GParamSpec **
-gegl_list_properties (const gchar *operation_type,
-                      guint       *n_properties_p)
+gegl_operation_list_properties (const gchar *operation_type,
+                                guint       *n_properties_p)
 {
   GParamSpec  **pspecs;
   GType         type;
diff --git a/gegl/operation/gegl-operation.h b/gegl/operation/gegl-operation.h
index 7255e77..39100f0 100644
--- a/gegl/operation/gegl-operation.h
+++ b/gegl/operation/gegl-operation.h
@@ -216,8 +216,7 @@ const gchar *   gegl_operation_get_name      (GeglOperation *operation);
 GeglNode      * gegl_operation_get_source_node (GeglOperation *operation,
                                                 const gchar   *pad_name);
 
-/* XXX: should be changed to gegl_op_list_properties */
-GParamSpec ** gegl_list_properties             (const gchar *operation_type,
+GParamSpec ** gegl_operation_list_properties   (const gchar *operation_type,
                                                 guint       *n_properties_p);
 
 /* API to change  */



[Date Prev][Date Next]   [Thread Prev][Thread Next]   [Thread Index] [Date Index] [Author Index]
diff --git a/gegl/gegl.h b/gegl/gegl.h
index 61e9daa..599b45e 100644
--- a/gegl/gegl.h
+++ b/gegl/gegl.h
@@ -121,7 +121,7 @@ void           gegl_exit                 (void);
  * Available operations:
  * Gegl provides means to check for available processing operations that
  * can be used with nodes using #gegl_list_operations and for a specified
  * op give a list of properties with #gegl_list_properties.
  */
 
 /**
@@ -147,14 +147,14 @@ gchar        **gegl_list_operations         (guint *n_operations_p);
 
 
 /**
- * gegl_list_properties:
+ * gegl_operation_list_properties:
  * @operation_type: the name of the operation type we want to query to properties of.
  * @n_properties_p: return location for number of properties.
  *
  * Return value: (transfer container): An allocated array of #GParamSpecs describing the properties
  * of the operation available when a node has operation_type set.
  */
-GParamSpec** gegl_list_properties           (const gchar   *operation_type,
+GParamSpec** gegl_operation_list_properties           (const gchar   *operation_type,
                                              guint         *n_properties_p);
 
 /***
@@ -121,7 +121,7 @@ void           gegl_exit                 (void);
  * Gegl provides means to check for available processing operations that
  * can be used with nodes using #gegl_list_operations and for a specified
- * op give a list of properties with #gegl_list_properties.
+ * op give a list of properties with #gegl_operation_list_properties.
  */
 